==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/plugins/e2p_names_clip.c <==
/*
 *
 * Copyright (C) 2003-2005 tooar <tooar@gmx.net>
 * Portions copyright (C) 1999 Michael Clark
 *
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include <string.h>
#include "e2_plugins.h"

static void _e2p_copy_to_clipboard (void)
{
	GString *text = NULL;
	gboolean completed = FALSE;
	GdkModifierType state;
	if (gtk_get_current_event_state (&state))
	{
		guint modifiers = gtk_accelerator_get_default_mod_mask ();
		if ((state & modifiers) == GDK_SHIFT_MASK)
		{
			//get quoted list of selected item names
			text = e2_utils_expand_macros ("%f", NULL);
			if (text == NULL)
				return;

			gchar **split = g_strsplit (text->str, "\"", -1);
			gchar **tmp = split;
			g_string_assign (text, "");
			while (*tmp != NULL)
			{
				if (**tmp == '\0')	//empty string before 1st " and after last "
				{
					tmp++;
					continue;
				}
				else if (**tmp == ' ')
					text = g_string_append_c (text, ' ');
				else
				{
					text = g_string_append (text, curr_view->dir);
					text = g_string_append (text, *tmp);
				}
				tmp++;
			}
			g_strfreev (split);
			completed = TRUE;
		}
	}
	if (!completed)
	{
		//get un-quoted list of selected item names
		text = e2_utils_expand_macros ("%%f", NULL);
		if (text == NULL)
			return;
	}

	GtkClipboard *clip = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
  	gtk_clipboard_set_text (clip, text->str, text->len);
	g_string_free (text, TRUE);
}

//aname must be confined to this module
static gchar *aname;
/**
 * @brief plugin initialization function, called by main program
 *
 * @param p ptr to plugin data struct
 *
 * @return TRUE if the initialization succeeds, else FALSE
 **/
gboolean init_plugin (Plugin *p)
{
#define ANAME "names_to_clipboard"
  aname = _("names_to_clipboard");
	
  p->signature = ANAME VERSION;
  p->menu_name = _("Copy _names");
  p->description = _("Copy path or name of each selected each to the clipboard");
  p->icon = ICON_DIR"plugin_clip_"E2IP".png";  //use icon file pathname if appropriate

  if (p->plugin_cb == NULL)
  {
	  p->plugin_cb = _e2p_copy_to_clipboard;  //set plugins menu item function
//	  E2_Action* (*action_register) () = (*p->api_lookup) (E2API_ACTION_REGISTER);
	  //no need to free this
	  gchar *action_name = g_strconcat (PLUGIN,".",aname,NULL);
	  //NULL = no data, FALSE = no argument for the function
//	  (*action_register)
	  e2_action_register_simple (action_name, E2_ACTION_TYPE_ITEM, _e2p_copy_to_clipboard, NULL, FALSE);
	  return TRUE;
  }
  return FALSE;
}
/**
 * @brief unload this plugin
 *
 * @param p pointer to data struct for the plugin
 *
 * @return
 **/
void unload_plugin (Plugin *p)
{
//  if (p->api_lookup != NULL)
//  {
//	  gboolean (*action_unregister) () = (*p->api_lookup) (E2API_ACTION_UNREGISTER);
	  gchar *action_name = g_strconcat (PLUGIN,".",aname,NULL);
//	  (*action_unregister)
	  e2_action_unregister (action_name);
	  g_free (action_name);
//  }
}

==> emelfm2-0.1.4.tar.gz: emelfm2-0.1.4/plugins/e2p_names_clip.c <==
/* $Id: e2p_names_clip.c 1306 2005-10-20 20:58:48Z tpgww $
 *
 * Copyright (C) 2003-2005 tooar <tooar@gmx.net>
 * Portions copyright (C) 1999 Michael Clark
 *
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include <string.h>
#include "e2_plugins.h"

static void _e2p_copy_to_clipboard (void)
{
	GString *text = NULL;
	gboolean completed = FALSE;
	GdkModifierType state;
	if (gtk_get_current_event_state (&state))
	{
		guint modifiers = gtk_accelerator_get_default_mod_mask ();
		if ((state & modifiers) == GDK_SHIFT_MASK)
		{
			//get quoted list of selected item names
			text = e2_utils_expand_macros ("%f", NULL);
			if (text == NULL)
				return;

			gchar **split = g_strsplit (text->str, "\"", -1);
			gchar **tmp = split;
			g_string_assign (text, "");
			while (*tmp != NULL)
			{
				if (**tmp == '\0')	//empty string before 1st " and after last "
				{
					tmp++;
					continue;
				}
				else if (**tmp == ' ')
					text = g_string_append_c (text, ' ');
				else
				{
					text = g_string_append (text, curr_view->dir);
					text = g_string_append (text, *tmp);
				}
				tmp++;
			}
			g_strfreev (split);
			completed = TRUE;
		}
	}
	if (!completed)
	{
		//get un-quoted list of selected item names
		text = e2_utils_expand_macros ("%%f", NULL);
		if (text == NULL)
			return;
	}

	GtkClipboard *clip = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
  	gtk_clipboard_set_text (clip, text->str, text->len);
	g_string_free (text, TRUE);
}

//aname must be confined to this module
static gchar *aname;
/**
 * @brief plugin initialization function, called by main program
 *
 * @param p ptr to plugin data struct
 *
 * @return TRUE if the initialization succeeds, else FALSE
 **/
gboolean init_plugin (Plugin *p)
{
#define ANAME "names_to_clipboard"
  aname = _("names_to_clipboard");
	
  p->signature = ANAME VERSION;
  p->menu_name = _("Copy _names");
  p->description = _("Copy path or name of each selected each to the clipboard");
  p->icon = "plugin_clip_"E2IP".png";  //use icon file pathname if appropriate

  if (p->plugin_cb == NULL)
  {
	  p->plugin_cb = _e2p_copy_to_clipboard;  //set plugins menu item function
//	  E2_Action* (*action_register) () = (*p->api_lookup) (E2API_ACTION_REGISTER);
	  //no need to free this
	  gchar *action_name = g_strconcat (PLUGIN,".",aname,NULL);
	  //NULL = no data, FALSE = no argument for the function
//	  (*action_register)
	  e2_action_register_simple (action_name, E2_ACTION_TYPE_ITEM, _e2p_copy_to_clipboard, NULL, FALSE);
	  return TRUE;
  }
  return FALSE;
}
/**
 * @brief unload this plugin
 *
 * @param p pointer to data struct for the plugin
 *
 * @return
 **/
void unload_plugin (Plugin *p)
{
//  if (p->api_lookup != NULL)
//  {
//	  gboolean (*action_unregister) () = (*p->api_lookup) (E2API_ACTION_UNREGISTER);
	  gchar *action_name = g_strconcat (PLUGIN,".",aname,NULL);
//	  (*action_unregister)
	  e2_action_unregister (action_name);
	  g_free (action_name);
//  }
}
